@@ -9,7 +9,7 @@ require 5.010000;
 
 use feature 'state';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Carp;
 
@@ -19,7 +19,7 @@ use Ref::Util qw< is_arrayref is_ref is_coderef  >;
 
 use custom::failures;
 use Package::Stash;
-use Hash::Wrap { -as => '_wrap_hash' };
+use Hash::Wrap ( { -as => '_wrap_hash' } );
 
 use PDL::Algorithm::Center::Failure ':all';
 
@@ -1308,7 +1308,7 @@ PDL::Algorithm::Center - Various methods of finding the center of a sample
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 DESCRIPTION
 
